@@ -18,9 +18,10 @@ sub validate_args {
     for (qw(line column replacement)) {
         $self->usage_error("Arg $_ is required") unless $opt->{$_};
     }
+    return 1;
 }
 
-sub run {
+sub execute {
     my ( $self, $opt, $arg ) = @_;
 
     my $doc_as_str = join( "", <STDIN> );
